@@ -23,6 +23,7 @@ import six.moves.urllib.parse as urlparse
 
 from os_collect_config import common
 from os_collect_config import exc
+from os_collect_config import merger
 from os_collect_config.openstack.common import log
 
 CONF = cfg.CONF
@@ -46,15 +47,14 @@ opts = [
                help='Access Key ID'),
     cfg.MultiStrOpt('deployment-key',
                     default=['deployments'],
-                    help='Key(s) to explode into multiple collected outputs. '
-                    'Parsed according to the expected Metadata created by '
-                    'OS::Heat::StructuredDeployment. Only Exploded if seen at '
-                    'the root of the Metadata.')
+                    help='DEPRECATED, use global configuration option '
+                         '"deployment-key"')
 ]
 name = 'cfn'
 
 
 class Collector(object):
+
     def __init__(self, requests_impl=common.requests):
         self._requests_impl = requests_impl
         self._session = requests_impl.Session()
@@ -66,20 +66,20 @@ class Collector(object):
                 with open(CONF.cfn.heat_metadata_hint) as hint:
                     CONF.cfn.metadata_url = '%s/v1/' % hint.read().strip()
             else:
-                logger.warn('No metadata_url configured.')
+                logger.info('No metadata_url configured.')
                 raise exc.CfnMetadataNotConfigured
         if CONF.cfn.access_key_id is None:
-            logger.warn('No Access Key ID configured.')
+            logger.info('No Access Key ID configured.')
             raise exc.CfnMetadataNotConfigured
         if CONF.cfn.secret_access_key is None:
-            logger.warn('No Secret Access Key configured.')
+            logger.info('No Secret Access Key configured.')
             raise exc.CfnMetadataNotConfigured
         url = CONF.cfn.metadata_url
         stack_name = CONF.cfn.stack_name
         headers = {'Content-Type': 'application/json'}
         final_content = {}
         if CONF.cfn.path is None:
-            logger.warn('No path configured')
+            logger.info('No path configured')
             raise exc.CfnMetadataNotConfigured
 
         signer = ec2_utils.Ec2Signer(secret_key=CONF.cfn.secret_access_key)
@@ -134,26 +134,6 @@ class Collector(object):
                             'Sub-key %s does not exist. (%s)' % (subkey, path))
                         raise exc.CfnMetadataNotAvailable
             final_content.update(value)
-        final_list = []
-        for depkey in cfg.CONF.cfn.deployment_key:
-            if depkey in final_content:
-                deployments = final_content[depkey]
-                if not isinstance(deployments, list):
-                    logger.warn(
-                        'Deployment-key %s was found but does not contain a '
-                        'list.' % (depkey,))
-                    continue
-                logger.debug(
-                    'Deployment found for %s' % (depkey,))
-                for deployment in deployments:
-                    if 'name' not in deployment:
-                        logger.warn(
-                            'No name found for a deployment under %s.' %
-                            (depkey,))
-                        continue
-                    if deployment.get('group', 'Heat::Ungrouped') in (
-                            'os-apply-config', 'Heat::Ungrouped'):
-                        final_list.append((deployment['name'],
-                                           deployment['config']))
-        final_list.insert(0, ('cfn', final_content))
+        final_list = merger.merged_list_from_content(
+            final_content, cfg.CONF.cfn.deployment_key, name)
         return final_list
